@@ -32,7 +32,7 @@ entity_type_string_to_class = {
     "Place": Place,
     "Event": Event,
     "Work": Work,
-    "Insitution": Institution,
+    "Institution": Institution,
 }
 
 relation_type_to_tei_tag = {
@@ -45,7 +45,7 @@ relation_type_to_tei_tag = {
 
 class TeiEntCreator:
     def __init__(
-        self, ent_dict, base_url="apis/api2/", include_entity_tagged_texts=False
+        self, ent_dict, base_url="entity/", include_entity_tagged_texts=False
     ):
         """
         Entry point: called from apis_core/apis_entities/api_renderers.py
@@ -160,9 +160,11 @@ class TeiEntCreator:
                 node = ET.Element("orgName")
                 node.attrib["type"] = "alt"
                 try:
-                    node.attrib["subtype"] = "{}".format(x["label_type"]["name"])
+                    node_subtype = f'{x["label_type"]["name"]}'
                 except KeyError:
-                    pass
+                    node_subtype = False
+                if node_subtype:
+                    node.attrib["subtype"] = slugify(node_subtype)
                 try:
                     node.attrib[
                         "{http://www.w3.org/XML/1998/namespace}lang"
@@ -176,11 +178,11 @@ class TeiEntCreator:
         if self.ent_dict.get("end_date"):
             orgName.attrib["notAfter"] = self.ent_dict.get("end_date")
         org.append(orgName)
-        for x in self.relation_notes():
-            org.append(x)
         if self.uris_to_idnos():
             for x in self.uris_to_idnos():
                 org.append(x)
+        for x in self.relation_notes():
+            org.append(x)
         return org
 
     def create_place_node(self):
@@ -200,9 +202,11 @@ class TeiEntCreator:
                 node = ET.Element("placeName")
                 node.attrib["type"] = "alt"
                 try:
-                    node.attrib['subtype'] = "{}".format(x['label_type']['name'])
-                except (KeyError, TypeError):
-                    pass
+                    node_subtype = f'{x["label_type"]["name"]}'
+                except KeyError:
+                    node_subtype = False
+                if node_subtype:
+                    node.attrib["subtype"] = slugify(node_subtype)
                 try:
                     node.attrib[
                         "{http://www.w3.org/XML/1998/namespace}lang"
@@ -211,11 +215,6 @@ class TeiEntCreator:
                     pass
                 node.text = x["label"]
                 place.append(node)
-        for x in self.relation_notes():
-            place.append(x)
-        if self.uris_to_idnos():
-            for x in self.uris_to_idnos():
-                place.append(x)
         if self.ent_dict.get("lat"):
             coords = "{} {}".format(self.ent_dict["lat"], self.ent_dict["lng"])
             location = ET.Element("location")
@@ -223,6 +222,11 @@ class TeiEntCreator:
             geo.text = coords
             location.append(geo)
             place.append(location)
+        for x in self.relation_notes():
+            place.append(x)
+        if self.uris_to_idnos():
+            for x in self.uris_to_idnos():
+                place.append(x)
         return place
 
     def create_person_node(self):
@@ -244,9 +248,11 @@ class TeiEntCreator:
                 node = ET.Element("persName")
                 node.attrib["type"] = "alt"
                 try:
-                    node.attrib["subtype"] = "{}".format(x["label_type"]["name"])
+                    node_subtype = f'{x["label_type"]["name"]}'
                 except KeyError:
-                    pass
+                    node_subtype = False
+                if node_subtype:
+                    node.attrib["subtype"] = slugify(node_subtype)
                 try:
                     node.attrib[
                         "{http://www.w3.org/XML/1998/namespace}lang"
@@ -291,7 +297,7 @@ class TeiEntCreator:
         return person
 
     def populate_header(self):
-        main = "{}: {}".format(self.ent_type, self.ent_name)
+        main = f"{self.ent_type}: {self.ent_name}"
         header = self.gen_tei_header.format(main, self.project)
         return header
 
